# netsome

# About

TBD

# Authors

- Dmitriy Kudryavtsev - author - [kuderr](https://github.com/kuderr)

Special thanks to [Dima Burmistrov](https://gitlab.com/pyctrl) for inspiration and lessons on how to make libraries and good interfaces. ASN type v1 was crafted within our dev team.
